import React, {
  useState,
  DragEvent,
  MouseEvent,
  useRef,
  useEffect,
} from "react";

const WidgetsFloating: React.FC = () => {
  const stateWorking = [
    { "Oil Tank": "24/341" },
    { "Oil Refin": "36.023" },
    { Transmission: "36.023" },
    { Fuel: "36732" },
    { Power: "1300" },
    { Time: "13-9-2023" },
  ];

  // State for storing the dragged widget and its position
  const [draggedFloating, setDraggedFloating] = useState<string | null>(null);
  const [position, setPosition] = useState<{ x: number; y: number }>({
    x: 0,
    y: 0,
  });

  // State to store all placed widgets with their positions
  const [placedWidgets, setPlacedWidgets] = useState<
    { name: string; x: number; y: number }[]
  >([]);

  const canvasRef = useRef<HTMLDivElement>(null);

  // Handle the drag start event
  const handleDragStart = (
    event: DragEvent<HTMLDivElement>,
    widget: string
  ) => {
    setDraggedFloating(widget);
    // Initialize position to the current position when drag starts
    setPosition({ x: event.clientX, y: event.clientY });
  };

  // Handle the drag move event
  const handleDragMove = (event: MouseEvent) => {
    if (!draggedFloating) return;

    // Calculate new position and update it
    const canvas = canvasRef.current;
    if (canvas) {
      const canvasRect = canvas.getBoundingClientRect();
      const newX = event.clientX - canvasRect.left;
      const newY = event.clientY - canvasRect.top;
      setPosition({ x: newX, y: newY });
    }
  };

  // Handle the drag end event
  const handleDragEnd = () => {
    if (draggedFloating) {
      // Store the final position of the dragged widget
      setPlacedWidgets((prevWidgets) => [
        ...prevWidgets,
        { name: draggedFloating, x: position.x, y: position.y },
      ]);
      // Reset the dragged floating widget after dragging is completed
      setDraggedFloating(null);
    }
  };

  useEffect(() => {
    console.log("position: ", position);
    console.log("draggedFloating: ", draggedFloating);
  }, [draggedFloating, position]);

  return (
    <div
      id="real-time-vis-canvas"
      ref={canvasRef}
      className="canvas"
      style={{
        position: "relative",
        width: "100%",
        height: "400px",
        backgroundColor: "#f0f0f0",
        border: "1px solid #ccc",
      }}
      onMouseMove={handleDragMove}
      onMouseUp={handleDragEnd}
    >
      {/* The floating widget that's being dragged */}
      {draggedFloating && (
        <div
          className="floating"
          style={{
            position: "absolute",
            left: `${position.x}px`,
            top: `${position.y}px`,
            cursor: "move",
            backgroundColor: "lightblue",
            padding: "10px",
            borderRadius: "5px",
          }}
        >
          {draggedFloating}
        </div>
      )}

      {/* Render all placed widgets */}
      {placedWidgets.map((widget, index) => (
        <div
          key={index}
          className="floating"
          style={{
            position: "absolute",
            left: `${widget.x}px`,
            top: `${widget.y}px`,
            backgroundColor: "lightgreen",
            padding: "10px",
            borderRadius: "5px",
          }}
        >
          {widget.name}
        </div>
      ))}

      {/* The rest of your floating widgets */}
      <div
        className="floating working-state"
        draggable
        onDragStart={(e) => handleDragStart(e, "working-state")}
        style={{ position: "absolute", top: "50px", left: "50px" }}
      >
        <div className="state-working-top">
          <div className="state-working-main">
            <div className="state">State</div>
            <div className="working-status">
              <span className="working">Working</span>
              <span className="dot"></span>
            </div>
          </div>
          <div className="img">
            <img
              src="https://source.unsplash.com/random/150x100/?factory"
              alt="Factory"
            />
          </div>
        </div>
        <div className="state-working-data">
          {stateWorking.map((state, index) => {
            const key = Object.keys(state)[0];
            const value = state[key];
            return (
              <div className="data-row" key={index}>
                <span className="data-key">{key}:</span>
                <span className="data-value">{value}</span>
              </div>
            );
          })}
        </div>
      </div>

      {/* Other floating widgets */}
      <div
        className="floating"
        draggable
        onDragStart={(e) => handleDragStart(e, "floating-2")}
        style={{ position: "absolute", top: "120px", left: "150px" }}
      >
        floating-2
      </div>
      <div
        className="floating"
        draggable
        onDragStart={(e) => handleDragStart(e, "floating-3")}
        style={{ position: "absolute", top: "200px", left: "250px" }}
      >
        floating-3
      </div>
      <div
        className="floating"
        draggable
        onDragStart={(e) => handleDragStart(e, "floating-4")}
        style={{ position: "absolute", top: "300px", left: "350px" }}
      >
        floating-4
      </div>
    </div>
  );
};

export default WidgetsFloating;